from __future__ import annotations

from django.conf import settings

CART_SESSION_KEY: str = getattr(settings, "CART_SESSION_KEY", "CART-ID")
CART_MANAGER_CLASS: str | None = getattr(settings, "CART_MANAGER_CLASS", None)
PERSIST_CART_TO_DB: bool = "cart" in settings.INSTALLED_APPS



from __future__ import annotations

from typing import Protocol, runtime_checkable

from django.http import HttpRequest


@runtime_checkable
class Storage(Protocol):
    request: HttpRequest

    def load(self) -> list[dict]:
        ...

    def save(self, items: list[dict]) -> None:
        ...

    def clear(self) -> None:
        ...



from __future__ import annotations

from importlib import import_module

Variant = str | int | dict | set


def check_variant_type(variant: Variant) -> None:
    if not isinstance(variant, Variant):
        raise ValueError(
            f"Invalid variant type :{type(variant)}, expected str, int, dict or set."
        )


def get_module(path: str):
    package, module = path.rsplit(".", 1)
    return getattr(import_module(package), module)



# Generated by Django 4.0.3 on 2022-03-03 11:42


from __future__ import annotations

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Cart",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("items", models.JSONField()),
                ("created", models.DateTimeField(default=django.utils.timezone.now)),
                ("modified", models.DateTimeField(auto_now_add=True)),
                (
                    "customer",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cart', 'cart.migrations', 'migrations']

package_data = \
{'': ['*']}

install_requires = \
['Django>=3', 'attrs>=21.4.0,<22.0.0']

setup_kwargs = {
    'name': 'dj-shop-cart',
    'version': '0.1.3',
    'description': 'Simple django cart manager for your django projects.',
    'long_description': None,
    'author': 'Tobi DEGNON',
    'author_email': 'tobidegnon@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Tobi-De/dj-shop-cart',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



from __future__ import annotations

from django.http import HttpRequest

from .cart import get_cart_manager_class

Cart = get_cart_manager_class()


def cart(request: HttpRequest) -> dict:
    return {"cart": Cart.new(request)}
